@@ -498,8 +498,8 @@ class Sheet:
         filenames = {}
 
     def sort_by(self, by: str, desc=False):
-        copied = [*self.data_rows]
-        result = []
+        copied: List[Row] = [*self.data_rows]
+        result: List[Row] = []
         for i in range(len(self.data_rows)):
             min = copied[0]
             for j in range(len(copied)):
@@ -511,7 +511,7 @@ class Sheet:
                         min = copied[j]
             copied.remove(min)
             result.append(min)
-        return result
+        self.data_rows = result
 
     def beautify(self, by: str) -> List[Row]:
         if isinstance(by, str):
